#ifndef __ES_SYS_MEMORY_H__
#define __ES_SYS_MEMORY_H__
#include <stdint.h>
#include "es_type.h"
#include "es_common.h"
#include "es_errno.h"
#include <linux/es_vb_user.h>

#ifdef __cplusplus
#if __cplusplus
extern "C" {
#endif
#endif /* __cplusplus */

#define ES_SYS_ERROR_BASE      ES_DEF_ERR(ES_ID_SYS, EN_ERR_LEVEL_ERROR, 0)
#define ES_SYS_ERROR_NUM(X) (ES_SYS_ERROR_BASE + X)

#define ES_SYS_ERROR_ILLEGAL_PARAM            ES_SYS_ERROR_NUM(EN_ERR_ILLEGAL_PARAM)
#define ES_SYS_ERROR_NULL_PTR                 ES_SYS_ERROR_NUM(EN_ERR_NULL_PTR)
#define ES_SYS_ERROR_NOT_CONFIG               ES_SYS_ERROR_NUM(EN_ERR_NOT_CONFIG)
#define ES_SYS_ERROR_NOT_SUPPORT              ES_SYS_ERROR_NUM(EN_ERR_NOT_SUPPORT)
#define ES_SYS_ERROR_NOT_PERM                 ES_SYS_ERROR_NUM(EN_ERR_NOT_PERM)
#define ES_SYS_ERROR_NOMEM                    ES_SYS_ERROR_NUM(EN_ERR_NOMEM)
#define ES_SYS_ERROR_NOBUF                    ES_SYS_ERROR_NUM(EN_ERR_NOBUF)
#define ES_SYS_ERROR_BADADDR                  ES_SYS_ERROR_NUM(EN_ERR_BADADDR)
#define ES_SYS_ERROR_SIZE_NOT_ENOUGH          ES_SYS_ERROR_NUM(EN_ERR_SIZE_NOT_ENOUGH)
#define ES_SYS_ERROR_DEV_NOT_FOUND            ES_SYS_ERROR_NUM(64)
#define ES_SYS_ERROR_DEV_NOT_OPEN             ES_SYS_ERROR_NUM(65)
#define ES_SYS_ERROR_OPERATION_FAIL           ES_SYS_ERROR_NUM(66)
#define ES_SYS_ERROR_FLUSH_CACHE_FAIL         ES_SYS_ERROR_NUM(67)
#define ES_SYS_ERROR_MEM_FREE_FAIL            ES_SYS_ERROR_NUM(68)
#define ES_SYS_ERROR_GET_SIZE_FAIL            ES_SYS_ERROR_NUM(69)
#define ES_SYS_ERROR_RETRIEVE_NODE_FAIL       ES_SYS_ERROR_NUM(70)


ES_S32 ES_SYS_MemAlloc(ES_U64 *memFd, SYS_CACHE_MODE_E cacheType,const ES_CHAR* pStrMmb, const ES_CHAR* strZone, ES_U64 len);
ES_S32 ES_SYS_MemFlushCache(ES_U64 memFd);
ES_S32 ES_SYS_MemFree(ES_U64 memFd);
ES_VOID* ES_SYS_Mmap(ES_U64 memFd,ES_U64 size, SYS_CACHE_MODE_E cacheType);
ES_S32 ES_SYS_Munmap(ES_VOID *pVirAddr, ES_U64 size );
ES_S32 ES_SYS_SplitMemFd(ES_U64 memFd, ES_U64 offset, ES_U64 len, ES_U64 *splitedMemFd);
ES_S32 ES_SYS_RcvMemFd(ES_U64 sndMemFd, ES_U64 *rcvdMemFd);
ES_S32 ES_SYS_Internal_GetFd(ES_U64 memFd);
ES_U64 ES_SYS_Internal_GetMemFd(ES_S32 fd);
ES_S32 ES_SYS_RetrieveMemNodeByFd(ES_U64 memFd, ES_S32 *nid);
ES_S32 ES_SYS_RetrieveMemNodeByVaddr(void *pVirAddr, ES_S32 *nid);
ES_S32 ES_SYS_GetMemSize (ES_U64 memFd, ES_U64 *size);

#ifdef __cplusplus
#if __cplusplus
}
#endif
#endif /* __cplusplus */

#endif

