#ifndef __ES_VB_MEMORY_H__
#define __ES_VB_MEMORY_H__
#include "es_type.h"
#include "es_common.h"
#include "es_defines.h"
#include "es_errno.h"
#include <linux/es_vb_user.h>

#ifdef __cplusplus
#if __cplusplus
extern "C" {
#endif
#endif /* __cplusplus */

#define ES_VB_ERROR_BASE      ES_DEF_ERR(ES_ID_VB, EN_ERR_LEVEL_ERROR, 0)
#define ES_VB_ERROR_NUM(X) (ES_VB_ERROR_BASE + X)

#define ES_VB_ERROR_ILLEGAL_PARAM            ES_VB_ERROR_NUM(EN_ERR_ILLEGAL_PARAM)
#define ES_VB_ERROR_NULL_PTR                 ES_VB_ERROR_NUM(EN_ERR_NULL_PTR)
#define ES_VB_ERROR_NOT_CONFIG               ES_VB_ERROR_NUM(EN_ERR_NOT_CONFIG)
#define ES_VB_ERROR_NOT_SUPPORT              ES_VB_ERROR_NUM(EN_ERR_NOT_SUPPORT)
#define ES_VB_ERROR_NOT_PERM                 ES_VB_ERROR_NUM(EN_ERR_NOT_PERM)
#define ES_VB_ERROR_NOMEM                    ES_VB_ERROR_NUM(EN_ERR_NOMEM)
#define ES_VB_ERROR_NOBUF                    ES_VB_ERROR_NUM(EN_ERR_NOBUF)
#define ES_VB_ERROR_BADADDR                  ES_VB_ERROR_NUM(EN_ERR_BADADDR)
#define ES_VB_ERROR_SIZE_NOT_ENOUGH          ES_VB_ERROR_NUM(EN_ERR_SIZE_NOT_ENOUGH)
#define ES_VB_ERROR_DEV_NOT_FOUND            ES_VB_ERROR_NUM(64)
#define ES_VB_ERROR_DEV_NOT_OPEN             ES_VB_ERROR_NUM(65)
#define ES_VB_ERROR_OPERATION_FAIL           ES_VB_ERROR_NUM(66)
#define ES_VB_ERROR_FLUSH_CACHE_FAIL         ES_VB_ERROR_NUM(67)
#define ES_VB_ERROR_CREAT_POOL_FAIL          ES_VB_ERROR_NUM(68)
#define ES_VB_ERROR_DESTROY_POOL_FAIL        ES_VB_ERROR_NUM(69)
#define ES_VB_ERROR_SET_CFG_FAIL             ES_VB_ERROR_NUM(70)
#define ES_VB_ERROR_GET_CFG_FAIL             ES_VB_ERROR_NUM(71)
#define ES_VB_ERROR_INIT_CFG_FAIL            ES_VB_ERROR_NUM(72)
#define ES_VB_ERROR_UNINIT_CFG_FAIL          ES_VB_ERROR_NUM(73)
#define ES_VB_ERROR_POOL_GET_SIZE_FAIL       ES_VB_ERROR_NUM(74)
#define ES_VB_ERROR_POOL_MMAP_FAIL           ES_VB_ERROR_NUM(75)
#define ES_VB_ERROR_POOL_ILLEGAL_POOLID      ES_VB_ERROR_NUM(76)
#define ES_VB_ERROR_POOL_UNMAP_FAIL          ES_VB_ERROR_NUM(77)
#define ES_VB_ERROR_POOL_NOT_MAP             ES_VB_ERROR_NUM(78)
#define ES_VB_ERROR_GET_IOVA_FAIL            ES_VB_ERROR_NUM(79)
#define ES_VB_ERROR_PUT_IOVA_FAIL            ES_VB_ERROR_NUM(80)
#define ES_VB_ERROR_SPLIT_DMABUF_FAIL        ES_VB_ERROR_NUM(81)
#define ES_VB_ERROR_GET_BLK_FAIL             ES_VB_ERROR_NUM(82)
#define ES_VB_ERROR_GET_BLK_OFFSET_FAIL      ES_VB_ERROR_NUM(83)
#define ES_VB_ERROR_FLUSH_POOL_FAIL          ES_VB_ERROR_NUM(84)
#define ES_VB_ERROR_GET_BLK_REFCNT_FAIL      ES_VB_ERROR_NUM(85)


ES_S32 ES_VB_CreatePool(VB_POOL_CONFIG_S *pstVbPoolCfg, VB_POOL *poolId);
ES_S32 ES_VB_DestroyPool(VB_POOL poolId);
ES_S32 ES_VB_GetBlock(VB_POOL poolId, ES_U64 blkSize,const ES_CHAR * strZone, ES_U64 *memFd);
ES_S32 ES_VB_ReleaseBlock(ES_U64 memFd);
ES_S32 ES_VB_AllocIOVA(ES_U64 memFd, VB_UID_E enVbUid, ES_VOID **ppIOVA);
ES_S32 ES_VB_IOVA2Handle(VB_UID_E enVbUid, ES_VOID *pIOVA, ES_U64 *memFd);
ES_S32 ES_VB_FreeIOVA(VB_UID_E enVbUid, ES_U64 memFd);
ES_S32 ES_VB_Handle2PoolId(ES_U64 memFd);
ES_S32 ES_VB_MmapPool(VB_POOL poolId);
ES_S32 ES_VB_MunmapPool(VB_POOL poolId);
ES_S32 ES_VB_GetBlockVirAddr (VB_POOL poolId, ES_U64 memFd,ES_VOID **ppVirAddr);
ES_S32 ES_VB_SetModPoolConfig(VB_UID_E enVbUid, const VB_CONFIG_S *pVbConfig);
ES_S32 ES_VB_GetModPoolConfig(VB_UID_E enVbUid, VB_CONFIG_S *pVbConfig);
ES_S32 ES_VB_ModPoolInit(VB_UID_E enVbUid);
ES_S32 ES_VB_ModPoolExit(VB_UID_E enVbUid);
ES_S32 ES_VB_GetModBlock(VB_UID_E enVbUid, ES_U64 blkSize,const ES_CHAR * strZone, ES_U64 *memFd);
ES_S32 ES_VB_SetConfig(const VB_CONFIG_S *pVbConfig);
ES_S32 ES_VB_GetConfig(VB_CONFIG_S *pVbConfig);
ES_S32 ES_VB_GetBlockRefCount(ES_U64 memFd, ES_U64 *blkFileCnt);
ES_S32 ES_VB_Init(ES_VOID);
ES_S32 ES_VB_Exit(ES_VOID);


#ifdef __cplusplus
#if __cplusplus
}
#endif
#endif /* __cplusplus */

#endif

